@@ -2,6 +2,7 @@
 Configuration file for the Sphinx documentation builder.
 """
 # -- stdlib imports ------------------------------------------------------------
+
 import os
 import sys
 import datetime
@@ -10,6 +11,7 @@ import warnings
 from packaging.version import Version
 
 # -- Read the Docs Specific Configuration --------------------------------------
+
 # This needs to be done before sunpy is imported
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 if on_rtd:
@@ -20,6 +22,7 @@ if on_rtd:
     os.environ['PARFIVE_HIDE_PROGRESS'] = 'True'
 
 # -- Check for dependencies ----------------------------------------------------
+
 from sunpy.util import missing_dependencies_by_extra
 
 missing_requirements = missing_dependencies_by_extra("sunpy")["docs"]
@@ -41,8 +44,23 @@ import sunpy
 from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyPendingDeprecationWarning
 
 # -- Project information -------------------------------------------------------
-project = 'sunpy'
-author = 'The SunPy Community'
+
+# The full version, including alpha/beta/rc tags
+from sunpy import __version__
+
+_version = Version(__version__)
+version = release = str(_version)
+# Avoid "post" appearing in version string in rendered docs
+if _version.is_postrelease:
+    version = release = _version.base_version
+# Avoid long githashes in rendered Sphinx docs
+elif _version.is_devrelease:
+    version = release = f"{_version.base_version}.dev{_version.dev}"
+is_development = _version.is_devrelease
+is_release = not(_version.is_prerelease or _version.is_devrelease)
+
+project = "sunpy"
+author = "The SunPy Community"
 copyright = f'{datetime.datetime.now().year}, {author}'
 
 # Register remote data option with doctest
@@ -50,13 +68,6 @@ import doctest
 
 REMOTE_DATA = doctest.register_optionflag('REMOTE_DATA')
 
-# The full version, including alpha/beta/rc tags
-from sunpy import __version__
-
-release = __version__
-sunpy_version = Version(__version__)
-is_release = not(sunpy_version.is_prerelease or sunpy_version.is_devrelease)
-
 # We want to make sure all the following warnings fail the build
 warnings.filterwarnings("error", category=SunpyDeprecationWarning)
 warnings.filterwarnings("error", category=SunpyPendingDeprecationWarning)
@@ -64,6 +75,7 @@ warnings.filterwarnings("error", category=MatplotlibDeprecationWarning)
 warnings.filterwarnings("error", category=AstropyDeprecationWarning)
 
 # -- SunPy Sample Data and Config ----------------------------------------------
+
 # We set the logger to debug so that we can see any sample data download errors
 # in the CI, especially RTD.
 ori_level = sunpy.log.level
@@ -87,6 +99,7 @@ linkcheck_ignore = [
 linkcheck_anchors = False
 
 # -- General configuration ---------------------------------------------------
+
 # sphinxext-opengraph
 ogp_image = "https://raw.githubusercontent.com/sunpy/sunpy-logo/master/generated/sunpy_logo_word.png"
 ogp_use_first_image = True
@@ -212,6 +225,7 @@ intersphinx_mapping = {
 }
 
 # -- Options for hoverxref -----------------------------------------------------
+
 if os.environ.get("READTHEDOCS"):
     hoverxref_api_host = "https://readthedocs.org"
 
@@ -245,6 +259,7 @@ hoverxref_role_types = {
 }
 
 # -- Options for HTML output ---------------------------------------------------
+
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 html_theme = "sunpy"
@@ -267,6 +282,7 @@ graphviz_dot_args = [
 ]
 
 # -- Sphinx Gallery ------------------------------------------------------------
+
 # JSOC email os env
 # see https://github.com/sunpy/sunpy/wiki/Home:-JSOC
 os.environ["JSOC_EMAIL"] = "jsoc@sunpy.org"
@@ -299,6 +315,7 @@ sphinx_gallery_conf = {
 }
 
 # -- Linking to OpenCV docs by using rst_epilog --------------------------------
+
 try:
     import requests
     from bs4 import BeautifulSoup
@@ -335,11 +352,13 @@ rst_epilog = f"""
 """
 
 # -- Options for sphinx-copybutton ---------------------------------------------
+
 # Python Repl + continuation, Bash, ipython and qtconsole + continuation, jupyter-console + continuation
 copybutton_prompt_text = r">>> |\.\.\. |\$ |In \[\d*\]: | {2,5}\.\.\.: | {5,8}: "
 copybutton_prompt_is_regexp = True
 
 # -- Stability Page ------------------------------------------------------------
+
 with open('./reference/sunpy_stability.yaml') as estability:
     yaml = YAML(typ='rt')
     sunpy_modules = yaml.load(estability.read())
@@ -381,6 +400,7 @@ def jinja_to_rst(app, docname, source):
 
 
 # -- Sphinx setup --------------------------------------------------------------
+
 def setup(app):
     # Handles the templating for the jinja pages in our docs
     app.connect("source-read", jinja_to_rst)
