@@ -15,8 +15,8 @@ This module contains the functions for converting one
 import logging
 from copy import deepcopy
 from functools import wraps
-from contextlib import contextmanager
 
+import erfa
 import numpy as np
 
 import astropy.units as u
@@ -39,13 +39,12 @@ from astropy.coordinates.representation import (
     SphericalRepresentation,
     UnitSphericalRepresentation,
 )
-# Import erfa via astropy to make sure we are using the same ERFA library as Astropy
-from astropy.coordinates.sky_coordinate import erfa
 from astropy.coordinates.transformations import FunctionTransform, FunctionTransformWithFiniteDifference
 from astropy.time import Time
 
 from sunpy import log
 from sunpy.sun import constants
+from sunpy.util.decorators import sunpycontextmanager
 from .frames import (
     _J2000,
     GeocentricEarthEquatorial,
@@ -75,7 +74,7 @@ _ignore_sun_motion = False
 _autoapply_diffrot = None
 
 
-@contextmanager
+@sunpycontextmanager
 def transform_with_sun_center():
     """
     Context manager for coordinate transformations to ignore the motion of the center of the Sun.
@@ -139,7 +138,7 @@ def transform_with_sun_center():
         _ignore_sun_motion = old_ignore_sun_motion
 
 
-@contextmanager
+@sunpycontextmanager
 def propagate_with_solar_surface(rotation_model='howard'):
     """
     Context manager for coordinate transformations to automatically apply solar
@@ -162,7 +161,7 @@ def propagate_with_solar_surface(rotation_model='howard'):
     rotation_model : `str`
         Accepted model names are ``'howard'`` (default), ``'snodgrass'``,
         ``'allen'``, and ``'rigid'``.  See the documentation for
-        :func:`~sunpy.physics.differential_rotation.diff_rot` for the differences
+        :func:`~sunpy.sun.models.differential_rotation` for the differences
         between these models.
 
     Notes
@@ -1150,7 +1149,7 @@ frame_transform_graph._add_merged_transform(Geomagnetic, ITRS, Geomagnetic)
 @_transformation_debug("MAG->SM")
 def mag_to_sm(magcoord, smframe):
     """
-    Convert from Geomagnetic (MAG) to Solar Magentic (SM)
+    Convert from Geomagnetic (MAG) to Solar Magnetic (SM)
     """
     if magcoord.obstime is None:
         raise ConvertError("To perform this transformation, the coordinate"
@@ -1199,7 +1198,7 @@ frame_transform_graph._add_merged_transform(SolarMagnetic, Geomagnetic, SolarMag
 @_transformation_debug("SM->GSM")
 def sm_to_gsm(smcoord, gsmframe):
     """
-    Convert from Solar Magentic (SM) to Geocentric Solar Magnetospheric (GSM)
+    Convert from Solar Magnetic (SM) to Geocentric Solar Magnetospheric (GSM)
     """
     if smcoord.obstime is None:
         raise ConvertError("To perform this transformation, the coordinate"
