@@ -61,8 +61,7 @@ class GreatArc:
 
     References
     ----------
-    [1] https://www.mathworks.com/matlabcentral/newsreader/view_thread/277881
-    [2] https://en.wikipedia.org/wiki/Great-circle_distance#Vector_version
+    https://en.wikipedia.org/wiki/Great-circle_distance#Vector_version
 
     Example
     -------
@@ -420,7 +419,7 @@ def solar_angle_equivalency(observer):
     <Quantity 1.00603718 arcsec>
     """
 
-    if not isinstance(observer, (SkyCoord, BaseCoordinateFrame)):
+    if not isinstance(observer, SkyCoord | BaseCoordinateFrame):
         raise TypeError(
             "Invalid input, observer must be of type SkyCoord or BaseCoordinateFrame.")
     if observer.obstime is None:
