@@ -90,7 +90,7 @@ class UnifiedResponse(Sequence):
         The first index is to the client and the second index is the records
         returned from those clients.
         """
-        if isinstance(aslice, (int, slice)):
+        if isinstance(aslice, int | slice):
             ret = self._list[aslice]
 
         # using the client's name for indexing the responses.
@@ -119,7 +119,7 @@ class UnifiedResponse(Sequence):
         else:
             raise IndexError("UnifiedResponse objects must be sliced with integers or strings.")
 
-        if isinstance(ret, (QueryResponseTable, QueryResponseColumn, QueryResponseRow)):
+        if isinstance(ret, QueryResponseTable | QueryResponseColumn | QueryResponseRow):
             return ret
 
         return UnifiedResponse(*ret)
@@ -368,7 +368,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         """
         if path is None:
             path = Path(config.get('downloads', 'download_dir')) / '{file}'
-        elif isinstance(path, (str, os.PathLike)) and '{file}' not in str(path):
+        elif isinstance(path, str | os.PathLike) and '{file}' not in str(path):
             path = Path(path) / '{file}'
         else:
             path = Path(path)
@@ -478,11 +478,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         results = []
         for client in candidate_widget_types:
             tmpclient = client()
-            kwargs = dict()
-            # Handle the change in response format in the VSO
-            if isinstance(tmpclient, vso.VSOClient):
-                kwargs = dict(response_format="table")
-            results.append(tmpclient.search(*query, **kwargs))
+            results.append(tmpclient.search(*query))
 
         # This method is called by `search` and the results are fed into a
         # UnifiedResponse object.
